<?php

declare(strict_types=1);

namespace Dedi\SyliusCustomerReferralPlugin\Domain\Referral\UseCase\Invite;

use Dedi\SyliusCustomerReferralPlugin\Domain\Referral\DTO\ReferralDTO;
use Dedi\SyliusCustomerReferralPlugin\Domain\Referral\Model\InviterModelInterface;

final class InviteInput
{
    /** @var InviterModelInterface */
    private $inviter;

    /** @var array|null */
    private $emails;

    /** @var string|null */
    private $message;

    public static function createWithEmails(array $emails = ['']): self
    {
        $input = new self();
        $input->emails = $emails;
        $input->message = '';

        return $input;
    }

    public static function create(
        InviterModelInterface $inviter,
        array $emails,
        ?string $message
    ) {
        $input = new self();
        $input->inviter = $inviter;
        $input->emails = $emails;
        $input->message = $message;

        return $input;
    }

    public function getEmails(): ?array
    {
        return $this->emails;
    }

    public function getMessage(): ?string
    {
        return $this->message;
    }

    public function toReferralDTOs(): array
    {
        $dtos = array_map(function ($email) {
            return $email ? new ReferralDTO($this->inviter, $email) : null;
        }, $this->emails);

        return array_filter($dtos);
    }
}
